@@ -14,10 +14,12 @@ from .backends import get_load_dump_from_path
 # else we will not be able to load the saved caches.
 from dict_hash import sha256
 
+
 def cache(function):
     """Cache with default parameters"""
     return Cache()(function)
 
+
 class Cache:
     def __init__(
         self,
@@ -25,10 +27,11 @@ class Cache:
         args_to_ignore: Tuple[str] = (),
         cache_dir: str = None,
         validity_duration: Union[int, str] = -1,
-        use_source_code: bool = False,
+        use_source_code: bool = True,
         verbose: bool = False,
     ):
-        """Cache the results of a function (or method).
+        """
+        Cache the results of a function (or method).
 
         Example:
         ```
@@ -90,7 +93,7 @@ class Cache:
             If `validity_duration` is specified and a cache does not have it's json file, it's considered invalid.
             The given time must be an integer in seconds or a string in the format (\d+[smhdw]) to specify 
             a given ammount of s(econds), m(inutes), h(ours), d(ays), w(eeks). 
-        use_source_code: bool = False,
+        use_source_code: bool = True,
             If in the computing of the hash the must also use the sourcecode of the cached function.
         verbose: bool = False,
             Set the logger level to DEBUG. Alternatively the logger is getted with
@@ -135,7 +138,9 @@ class Cache:
             # Get the sourcode of the funciton
             # This will be used in the hash so that old
             # Caches will not be loaded
-            self.function_info["source"] = "".join(inspect.getsourcelines(function))
+            self.function_info["source"] = "".join(
+                inspect.getsourcelines(function)[0]
+            )
 
     def _decorate_callable(self, function: Callable) -> Callable:
         # wraps to support pickling
